==> cv-dialog-sdk-4.13.1.tgz: package/src/js/catavolt/ppm/WorkPackageVisitor.js <==
import { RecordVisitor } from '../proxy/RecordVisitor';
/**
 *
 */
export class WorkPackageVisitor extends RecordVisitor {
    constructor(value) {
        super(value);
    }
    // --- State Management Helpers --- //
    // --- State Management --- //
    visitBriefcase() {
        return this.visitPropertyValueAt(WorkPackageVisitor.BRIEFCASE_PROPERTY_NAME);
    }
    visitClassification() {
        return this.visitPropertyValueAt(WorkPackageVisitor.CLASSIFICATION_PROPERTY_NAME);
    }
    visitConfig() {
        return this.visitPropertyValueAt(WorkPackageVisitor.CONFIG_PROPERTY_NAME);
    }
    visitContract() {
        return this.visitPropertyValueAt(WorkPackageVisitor.CONTRACT_PROPERTY_NAME);
    }
    visitCreationDate() {
        return this.visitPropertyValueAt(WorkPackageVisitor.CREATION_DATE_PROPERTY_NAME);
    }
    visitCreationUser() {
        return this.visitPropertyValueAt(WorkPackageVisitor.CREATION_USER_PROPERTY_NAME);
    }
    visitDescription() {
        return this.visitPropertyValueAt(WorkPackageVisitor.DESCRIPTION_PROPERTY_NAME);
    }
    visitDisciplines() {
        return this.visitPropertyValueAt(WorkPackageVisitor.DISCIPLINES_PROPERTY_NAME);
    }
    visitId() {
        return this.visitPropertyValueAt(WorkPackageVisitor.ID_PROPERTY_NAME);
    }
    visitLastUpdateDate() {
        return this.visitPropertyValueAt(WorkPackageVisitor.LAST_UPDATE_DATE_PROPERTY_NAME);
    }
    visitName() {
        return this.visitPropertyValueAt(WorkPackageVisitor.NAME_PROPERTY_NAME);
    }
    visitOrganizationsGroup() {
        return this.visitPropertyValueAt(WorkPackageVisitor.ORGANIZATIONS_GROUP_PROPERTY_NAME);
    }
    visitOwningGroup() {
        return this.visitPropertyValueAt(WorkPackageVisitor.OWNING_GROUP_PROPERTY_NAME);
    }
    visitUid() {
        return this.visitPropertyValueAt(WorkPackageVisitor.UID_PROPERTY_NAME);
    }
}
WorkPackageVisitor.BRIEFCASE_PROPERTY_NAME = 'briefcase';
WorkPackageVisitor.CLASSIFICATION_PROPERTY_NAME = 'Classification';
WorkPackageVisitor.CONFIG_PROPERTY_NAME = 'Config';
WorkPackageVisitor.CONTRACT_PROPERTY_NAME = 'Contract';
WorkPackageVisitor.CREATION_DATE_PROPERTY_NAME = 'Creation_Date';
WorkPackageVisitor.CREATION_USER_PROPERTY_NAME = 'Creation_User';
WorkPackageVisitor.DESCRIPTION_PROPERTY_NAME = 'Description';
WorkPackageVisitor.DISCIPLINES_PROPERTY_NAME = 'Disciplines';
WorkPackageVisitor.ID_PROPERTY_NAME = 'Id';
WorkPackageVisitor.LAST_UPDATE_DATE_PROPERTY_NAME = 'Last_Update_Date';
WorkPackageVisitor.NAME_PROPERTY_NAME = 'Name';
WorkPackageVisitor.ORGANIZATIONS_GROUP_PROPERTY_NAME = 'Organizations';
WorkPackageVisitor.OWNING_GROUP_PROPERTY_NAME = 'Owning_Group';
WorkPackageVisitor.UID_PROPERTY_NAME = 'UID';

==> cv-dialog-sdk-4.26.9.tgz: package/src/js/catavolt/ppm/WorkPackageVisitor.js <==
import { RecordVisitor } from "../proxy/RecordVisitor";
/**
 *
 */
export class WorkPackageVisitor extends RecordVisitor {
    constructor(value) {
        super(value);
    }
    // --- State Management Helpers --- //
    // --- State Management --- //
    visitBriefcase() {
        return this.visitPropertyValueAt(WorkPackageVisitor.BRIEFCASE_PROPERTY_NAME);
    }
    visitClassification() {
        return this.visitPropertyValueAt(WorkPackageVisitor.CLASSIFICATION_PROPERTY_NAME);
    }
    visitConfig() {
        return this.visitPropertyValueAt(WorkPackageVisitor.CONFIG_PROPERTY_NAME);
    }
    visitContract() {
        return this.visitPropertyValueAt(WorkPackageVisitor.CONTRACT_PROPERTY_NAME);
    }
    visitCreationDate() {
        return this.visitPropertyValueAt(WorkPackageVisitor.CREATION_DATE_PROPERTY_NAME);
    }
    visitCreationUser() {
        return this.visitPropertyValueAt(WorkPackageVisitor.CREATION_USER_PROPERTY_NAME);
    }
    visitDescription() {
        return this.visitPropertyValueAt(WorkPackageVisitor.DESCRIPTION_PROPERTY_NAME);
    }
    visitDisciplines() {
        return this.visitPropertyValueAt(WorkPackageVisitor.DISCIPLINES_PROPERTY_NAME);
    }
    visitId() {
        return this.visitPropertyValueAt(WorkPackageVisitor.ID_PROPERTY_NAME);
    }
    visitLastUpdateDate() {
        return this.visitPropertyValueAt(WorkPackageVisitor.LAST_UPDATE_DATE_PROPERTY_NAME);
    }
    visitName() {
        return this.visitPropertyValueAt(WorkPackageVisitor.NAME_PROPERTY_NAME);
    }
    visitOrganizationsGroup() {
        return this.visitPropertyValueAt(WorkPackageVisitor.ORGANIZATIONS_GROUP_PROPERTY_NAME);
    }
    visitOwningGroup() {
        return this.visitPropertyValueAt(WorkPackageVisitor.OWNING_GROUP_PROPERTY_NAME);
    }
    visitUid() {
        return this.visitPropertyValueAt(WorkPackageVisitor.UID_PROPERTY_NAME);
    }
}
WorkPackageVisitor.BRIEFCASE_PROPERTY_NAME = "briefcase";
WorkPackageVisitor.CLASSIFICATION_PROPERTY_NAME = "Classification";
WorkPackageVisitor.CONFIG_PROPERTY_NAME = "Config";
WorkPackageVisitor.CONTRACT_PROPERTY_NAME = "Contract";
WorkPackageVisitor.CREATION_DATE_PROPERTY_NAME = "Creation_Date";
WorkPackageVisitor.CREATION_USER_PROPERTY_NAME = "Creation_User";
WorkPackageVisitor.DESCRIPTION_PROPERTY_NAME = "Description";
WorkPackageVisitor.DISCIPLINES_PROPERTY_NAME = "Disciplines";
WorkPackageVisitor.ID_PROPERTY_NAME = "Id";
WorkPackageVisitor.LAST_UPDATE_DATE_PROPERTY_NAME = "Last_Update_Date";
WorkPackageVisitor.NAME_PROPERTY_NAME = "Name";
WorkPackageVisitor.ORGANIZATIONS_GROUP_PROPERTY_NAME = "Organizations";
WorkPackageVisitor.OWNING_GROUP_PROPERTY_NAME = "Owning_Group";
WorkPackageVisitor.UID_PROPERTY_NAME = "UID";
